pub struct M2BoneFlags(/* private fields */);Expand description
Bone flags as defined in the M2 format
Implementations
Sourceimpl M2BoneFlags
impl M2BoneFlags
Sourcepub const SPHERICAL_BILLBOARD: Self
pub const SPHERICAL_BILLBOARD: Self
Spherical billboard
Sourcepub const CYLINDRICAL_BILLBOARD_LOCK_X: Self
pub const CYLINDRICAL_BILLBOARD_LOCK_X: Self
Cylindrical billboard lock X
Sourcepub const CYLINDRICAL_BILLBOARD_LOCK_Y: Self
pub const CYLINDRICAL_BILLBOARD_LOCK_Y: Self
Cylindrical billboard lock Y
Sourcepub const CYLINDRICAL_BILLBOARD_LOCK_Z: Self
pub const CYLINDRICAL_BILLBOARD_LOCK_Z: Self
Cylindrical billboard lock Z
Sourcepub const TRANSFORMED: Self
pub const TRANSFORMED: Self
Transformed
Sourcepub const KINEMATIC_BONE: Self
pub const KINEMATIC_BONE: Self
Kinematic bone (requires physics)
Sourcepub const HELPER_BONE: Self
pub const HELPER_BONE: Self
Helper bone
Sourcepub const HAS_ANIMATION: Self
pub const HAS_ANIMATION: Self
Has animation
Sourcepub const ANIMATED_AT_HIGHER_LODS: Self
pub const ANIMATED_AT_HIGHER_LODS: Self
Has multiple animations at higher LODs
Sourcepub const HAS_PROCEDURAL_ANIMATION: Self
pub const HAS_PROCEDURAL_ANIMATION: Self
Has procedural animation
Sourceimpl M2BoneFlags
impl M2BoneFlags
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl M2BoneFlags
impl M2BoneFlags
Sourcepub const fn iter(&self) -> Iter<M2BoneFlags>
pub const fn iter(&self) -> Iter<M2BoneFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<M2BoneFlags>
pub const fn iter_names(&self) -> IterNames<M2BoneFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.