M2TrackResolver

Struct M2TrackResolver 

pub struct M2TrackResolver;
Resolver for M2Track animation data This loads the actual keyframe data from M2Array offsets

Implementations

Source

impl M2TrackResolver

pub fn resolve_timestamps<R: Read + Seek>( reader: &mut R, track: &M2Track<impl Clone>, ) -> Result<Vec<u32>>

Resolve timestamp data for a track

pub fn resolve_vec3_values<R: Read + Seek>( reader: &mut R, track: &M2TrackVec3, ) -> Result<Vec<C3Vector>>

Resolve Vec3 track values (translation/scale)

pub fn resolve_quat_values<R: Read + Seek>( reader: &mut R, track: &M2TrackQuat, ) -> Result<Vec<M2CompQuat>>

Resolve quaternion track values (rotation)

pub fn resolve_ranges<R: Read + Seek>( reader: &mut R, track: &M2Track<impl Clone>, ) -> Result<Option<Vec<u32>>>

Resolve range data for pre-WotLK tracks Ranges are stored as pairs of u32 values (start, end)